.. _overview:

##########
 Overview
##########

`anemoi-inference <https://github.com/ecmwf/anemoi-inference>`_ to
`earthkit-workflows <https://github.com/ecmwf/earthkit-workflows>`_.
This allows inference tasks to be run as part of a larger DAG. It
provides an API to directly create a graph consisting of initial
condition retrieval and model execution, or to run inference off other
source nodes which themselves are the initial conditions.
